@@ -6,6 +6,7 @@ use crate::rules::{
 };
 use console::strip_ansi_codes;
 use console::style;
+use log::info;
 use serde::Serialize;
 use std::convert::TryFrom;
 use std::fs::File;
@@ -108,6 +109,7 @@ impl std::convert::From<CheckSQLError> for CheckFilesError {
 pub fn check_files(
     paths: &[String],
     is_stdin: bool,
+    stdin_path: Option<String>,
     excluded_rules: Option<Vec<String>>,
 ) -> Result<Vec<ViolationContent>, CheckFilesError> {
     let excluded_rules = excluded_rules.unwrap_or_else(|| vec![]);
@@ -121,11 +123,14 @@ pub fn check_files(
     };
 
     if is_stdin {
+        info!("reading content from stdin");
         let sql = get_sql_from_stdin()?;
-        process_violations(&sql, "stdin")?;
+        let path = stdin_path.unwrap_or_else(|| "stdin".into());
+        process_violations(&sql, &path)?;
     }
 
     for path in paths {
+        info!("checking file path: {}", path);
         let sql = get_sql_from_path(path)?;
         process_violations(&sql, path)?;
     }
@@ -250,6 +255,16 @@ pub fn fmt_tty<W: io::Write>(f: &mut W, files: &[ViolationContent]) -> Result<()
             fmt_tty_violation(f, violation)?;
         }
     }
+    let total_violations = files.iter().map(|f| f.violations.len()).sum::<usize>();
+    let files_checked = files.len();
+    if total_violations == 0 {
+        writeln!(
+            f,
+            "Found 0 issues in {files_checked} {files} 🎉",
+            files_checked = files_checked,
+            files = if files_checked == 1 { "file" } else { "files" }
+        )?;
+    }
     Ok(())
 }
 
@@ -320,13 +335,13 @@ pub fn pretty_violations(
 
 pub fn print_violations<W: io::Write>(
     writer: &mut W,
-    violations: Vec<ViolationContent>,
+    file_reports: Vec<ViolationContent>,
     reporter: &Reporter,
 ) -> Result<(), std::io::Error> {
     match reporter {
-        Reporter::Gcc => fmt_gcc(writer, &violations),
-        Reporter::Json => fmt_json(writer, violations),
-        Reporter::Tty => fmt_tty(writer, &violations),
+        Reporter::Gcc => fmt_gcc(writer, &file_reports),
+        Reporter::Json => fmt_json(writer, file_reports),
+        Reporter::Tty => fmt_tty(writer, &file_reports),
     }
 }
 
@@ -409,7 +424,7 @@ pub fn get_comment_body(files: Vec<ViolationContent>) -> String {
     let violations_count: usize = files.iter().map(|x| x.violations.len()).sum();
     format!(
         r#"
-# [Squawk](https://github.com/sbdchd/squawk) Report 🦉
+# [Squawk](https://github.com/sbdchd/squawk) Report
 
 ### **{violation_count}** violations across **{file_count}** file(s)
 
@@ -469,7 +484,7 @@ SELECT 1;
         let body = get_comment_body(violations);
 
         assert_display_snapshot!(body, @r###"
-# [Squawk](https://github.com/sbdchd/squawk) Report 🦉
+# [Squawk](https://github.com/sbdchd/squawk) Report
 
 ### **1** violations across **1** file(s)
 
@@ -542,7 +557,7 @@ ALTER TABLE "core_recipe" ADD COLUMN "foo" integer DEFAULT 10;
         let body = get_comment_body(violations);
 
         assert_display_snapshot!(body, @r###"
-# [Squawk](https://github.com/sbdchd/squawk) Report 🦉
+# [Squawk](https://github.com/sbdchd/squawk) Report
 
 ### **0** violations across **2** file(s)
 
@@ -609,7 +624,7 @@ None found.
         let body = get_comment_body(violations);
 
         assert_display_snapshot!(body, @r###"
-# [Squawk](https://github.com/sbdchd/squawk) Report 🦉
+# [Squawk](https://github.com/sbdchd/squawk) Report
 
 ### **0** violations across **0** file(s)
 
@@ -678,6 +693,21 @@ SELECT 1;
         // remove the color codes so tests behave in CI as they do locally
         assert_display_snapshot!(strip_ansi_codes(&String::from_utf8_lossy(&buff)));
     }
+    #[test]
+    fn test_display_no_violations_tty() {
+        let mut buff = Vec::new();
+
+        let res = print_violations(
+            &mut buff,
+            vec![pretty_violations(vec![], "", "main.sql")],
+            &Reporter::Tty,
+        );
+
+        assert!(res.is_ok());
+        // remove the color codes so tests behave in CI as they do locally
+        assert_display_snapshot!(strip_ansi_codes(&String::from_utf8_lossy(&buff)));
+    }
+
     #[test]
     fn test_display_violations_json() {
         let sql = r#" 
